Installation
============

The Invenio-DB package is on PyPI so all you need is:

.. code-block:: console

    $ pip install invenio-db

Invenio-DB depends on
`Flask-SQLAlchemy <https://Flask-SQLAlchemy.readthedocs.io/>`_.
